@@ -15,7 +15,7 @@ mix.print <- function(model,digits=3, ...){
    
 cat("\n Number of observations: ",model$n, "\n\n")
 
-if (inherits(model, 'Skew.normal') || inherits(model, 'Normal'))	cat("\n Hyperparameter(nu): ",model$nu, "\n\n")
+if (inherits(model, 'Skew.t') || inherits(model, 't'))	cat("\n Hyperparameter(nu): ",model$nu, "\n\n")
 
 if (inherits(model, 't') || inherits(model, 'Normal')){
    
@@ -36,7 +36,7 @@ if (inherits(model, 't') || inherits(model, 'Normal')){
    if(length(model$im.sdev) != 0 ) dimnames(estimates)[[1]] <- c("mu","sd","sigma2","sd")
    if(length(model$im.sdev) == 0 ) dimnames(estimates)[[1]] <- c("mu","sigma2")
 }
-if (inherits(model, 't') || inherits(model, 'Normal')){
+if (inherits(model, 'Skew.t') || inherits(model, 'Skew.normal')){
    if(length(model$im.sdev) != 0 ) {
         size <- length(model$im.sdev)
         if (inherits(model, 'Skew.normal')){
